pub struct ConceptNetClient { /* private fields */ }Expand description
Client for interacting with the ConceptNet API
Implementations
Sourceimpl ConceptNetClient
impl ConceptNetClient
Sourcepub fn new(config: Option<&ConceptNetConfig>) -> Result<Self>
pub fn new(config: Option<&ConceptNetConfig>) -> Result<Self>
Creates a new ConceptNetClient.
Uses the provided configuration or falls back to default values.
Fetches edges related to a ConceptNet URI.
Arguments
uri- AConceptNetURI (e.g., “/c/en/knowledge”) or term (e.g., “knowledge”)
If uri doesn’t start with a slash, it will be wrapped as an English
term (/c/en/{uri}).